==> huaweicloudsdkcodeartsgovernance-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcodeartsgovernance/v1/model/show_hm_report_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowHmReportResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'code': 'str',
        'data': 'HmVulnInfoData'
    }

    attribute_map = {
        'code': 'code',
        'data': 'data'
    }

    def __init__(self, code=None, data=None):
        """ShowHmReportResponse

        The model defined in huaweicloud sdk

        :param code: 响应码
        :type code: str
        :param data: 
        :type data: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoData`
        """
        
        super(ShowHmReportResponse, self).__init__()

        self._code = None
        self._data = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if data is not None:
            self.data = data

    @property
    def code(self):
        """Gets the code of this ShowHmReportResponse.

        响应码

        :return: The code of this ShowHmReportResponse.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ShowHmReportResponse.

        响应码

        :param code: The code of this ShowHmReportResponse.
        :type code: str
        """
        self._code = code

    @property
    def data(self):
        """Gets the data of this ShowHmReportResponse.

        :return: The data of this ShowHmReportResponse.
        :rtype: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoData`
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ShowHmReportResponse.

        :param data: The data of this ShowHmReportResponse.
        :type data: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoData`
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowHmReportResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsgovernance-3.1.143-py2.py3-none-any.whl: huaweicloudsdkcodeartsgovernance/v1/model/show_hm_report_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowHmReportResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'code': 'str',
        'data': 'HmVulnInfoData'
    }

    attribute_map = {
        'code': 'code',
        'data': 'data'
    }

    def __init__(self, code=None, data=None):
        r"""ShowHmReportResponse

        The model defined in huaweicloud sdk

        :param code: 响应码
        :type code: str
        :param data: 
        :type data: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoData`
        """
        
        super(ShowHmReportResponse, self).__init__()

        self._code = None
        self._data = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if data is not None:
            self.data = data

    @property
    def code(self):
        r"""Gets the code of this ShowHmReportResponse.

        响应码

        :return: The code of this ShowHmReportResponse.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        r"""Sets the code of this ShowHmReportResponse.

        响应码

        :param code: The code of this ShowHmReportResponse.
        :type code: str
        """
        self._code = code

    @property
    def data(self):
        r"""Gets the data of this ShowHmReportResponse.

        :return: The data of this ShowHmReportResponse.
        :rtype: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoData`
        """
        return self._data

    @data.setter
    def data(self, data):
        r"""Sets the data of this ShowHmReportResponse.

        :param data: The data of this ShowHmReportResponse.
        :type data: :class:`huaweicloudsdkcodeartsgovernance.v1.HmVulnInfoData`
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowHmReportResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
